const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const j = require('../../../json/leitorJson.po.js');
const bancoPage = require('../../../page-objects/parametrizacao/financeiro/banco.po');

const gridIdCobranca = '18500196513167922812484';
const gridIdTelaBanco = '1850019651335132358438';
const instrucao1Modificado = j.getValor('instrucaoCobranca1').concat(' Bancário');
const instrucao2Modificado = j.getValor('instrucaoCobranca2').replace(' em conta', '');

describe('Tela Banco', () => {
	beforeAll(() => {
		browser.get('http://erpteste.teknisa.com/login/');
		loginPage.login(j.getValor('login'), j.getValor('senha'));
		bancoPage.abrir();
		geral.clickAplicarFiltro();
	});

	afterAll(() => {
		geral.sair();
	});

	it('Acessar tela Banco', () => {
		geral.esperarLoading();
		expect(z.component.header.getTitle()).toBe('Banco');
	});

	it('Inserindo cadastro basico de banco', () => {
		bancoPage.adicionarBanco(j.getValor('codigoBanco'), j.getValor('nomeBanco'), j.getValor('mascaraAgencia'),
			j.getValor('mascaraConta'), j.getValor('codigoCompen'), j.getValor('bancoConv'),
			j.getValor('diasProrrog'));
		geral.filterIt(j.getValor('nomeBanco'));

		expect(geral.gridHasText(gridIdTelaBanco, j.getValor('nomeBanco'), 1))
			.toBe(j.getValor('nomeBanco'));
	});

	it('Inserindo Instruções de Cobrança', () => {
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		bancoPage.inserirInstrucaoDeCobranca('00', j.getValor('instrucaoCobranca1'));
		bancoPage.inserirInstrucaoDeCobranca('01', j.getValor('instrucaoCobranca2'));
		geral.esperarLoading();

		expect(geral.gridHasText(gridIdCobranca, j.getValor('instrucaoCobranca1'), 1))
			.toBe(j.getValor('instrucaoCobranca1'));
		expect(geral.gridHasText(gridIdCobranca, j.getValor('instrucaoCobranca2'), 1))
			.toBe(j.getValor('instrucaoCobranca2'));
	});

	it('Inserindo CNAB', () => {
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		geral.trocarAba('CNAB');
		geral.clickGrid('NMEMPRESA', j.getValor('empresa').concat(' Teknisa'), '18500196511813904182440');
		geral.clickEditar();
		bancoPage.alterarCNABporEmpresa(j.getValor('numeroCNAB'), j.getValor('tipoCNAB'),
			j.getValor('imprimeBoletoCNAB'), '00', '01', '7', j.getValor('diasProtesto'), '07', '08',
			j.getValor('formaCadastramentoCNAB'), '04');
		geral.waitFieldVisibility('IDCARTCOBR');
		geral.esperarLoading();

		expect(geral.getTextoPorId('CDCARTCOBR'))
			.toBe(j.getValor('numeroCNAB'));
		expect(geral.getTextoPorId('IDCARTCOBR'))
			.toBe(j.getValor('tipoCNAB'));
	});

	it('Adicionar DDA informando os campos obrigatórios', () => {
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		geral.trocarAba('DDA');
		bancoPage.editarDDA(j.getValor('diretorio'), j.getValor('email'));
		geral.waitFieldVisibility('DSDIRIMPARQDDA');

		expect(geral.getTextoPorId('DSDIRIMPARQDDA'))
			.toBe(j.getValor('diretorio'));
		expect(geral.getTextoPorId('DSEMAILDDA'))
			.toBe(j.getValor('email'));
	});

	it('Alterar DDA informando os campos obrigatórios', () => {
		const emailModificado = j.getValor('email').concat('.br');
		const diretorioImportModificado = j.getValor('diretorio').concat(' e afins');
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		geral.trocarAba('DDA');
		bancoPage.editarDDA(diretorioImportModificado, emailModificado);
		geral.waitFieldVisibility('DSDIRIMPARQDDA');

		expect(geral.getTextoPorId('DSDIRIMPARQDDA'))
			.toBe(diretorioImportModificado);
		expect(geral.getTextoPorId('DSEMAILDDA'))
			.toBe(emailModificado);
	});

	it('Alterar Instruções de Cobrança alterando os registros as descrições ', () => {
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		bancoPage.editarInstrucoesDeCobranca('00', instrucao1Modificado, gridIdCobranca);
		bancoPage.editarInstrucoesDeCobranca('01', instrucao2Modificado, gridIdCobranca);
		geral.clickVoltar();

		expect(geral.gridHasText(gridIdCobranca, instrucao1Modificado, 1))
			.toEqual(instrucao1Modificado);
		expect(geral.gridHasText(gridIdCobranca, instrucao2Modificado, 1))
			.toEqual(instrucao2Modificado);
	});

	it('Editar banco preexistente', () => {
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		geral.clickEditar();
		bancoPage.setDadosAbaBanco(j.getValor('nomeBanco').concat(' Express S.A.'), j.getValor('mascaraAgencia').concat('9'),
			j.getValor('mascaraConta').replace('9-9', ''),
			j.getValor('codigoCompen').concat('210'),
			j.getValor('bancoConv').concat('041'),
			j.getValor('diasProrrog').replace('5', '10'));
		geral.clickSalvar();
		geral.clickOk();
		geral.waitFieldVisibility('NMBANCO');

		expect(geral.getTextoPorId('NMBANCO'))
			.toEqual(j.getValor('nomeBanco').concat(' Express S.A.'));
		expect(geral.getTextoPorId('CDPICTAGEN'))
			.toEqual(j.getValor('mascaraAgencia').concat('9'));
		geral.clickVoltar();
	});

	it('Dever apagar todos os campos não obrigatórios', () => {
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		geral.trocarAba('CNAB');
		geral.clickGrid('CDEMPRESA', '00', '18500196511813904182440');
		geral.clickEditar();
		bancoPage.limpaCamposOpcionaisCNAB();
		geral.waitFieldVisibility('CDCARTCOBR');

		expect(geral.getTextoPorId('CDCARTCOBR'))
			.toBe('');
		expect(geral.getTextoPorId('IDCARTCOBR'))
			.toBe('');
		expect(geral.getTextoPorId('IDFORMCADBANC'))
			.toEqual(j.getValor('formaCadastramentoCNAB'));
	});

	it('Deve excluir Instruções de cobranças que não estejam relacionadas a registros', () => {
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		geral.trocarAba('Instruções de Cobrança');
		bancoPage.apagarInstrucoesCobranca(instrucao1Modificado, gridIdCobranca);
		bancoPage.apagarInstrucoesCobranca(instrucao2Modificado, gridIdCobranca);
		geral.esperarLoading();

		expect(geral.gridHasText(gridIdCobranca, instrucao1Modificado, 1))
			.toBeUndefined();
		expect(geral.gridHasText(gridIdCobranca, instrucao2Modificado, 1))
			.toBeUndefined();
	});

	it('Deve excluir um banco', () => {
		geral.clickGrid('CDBANCO', j.getValor('codigoBanco'), gridIdTelaBanco);
		geral.clickExcluir();
		geral.clickSim();
		geral.esperarLoading();

		expect(geral.gridHasText(gridIdTelaBanco, j.getValor('nomeBanco'), 1))
			.toBeUndefined();
	});
});
